@@ -308,12 +308,13 @@ synchronize_file(char *file_name, int is_system_startup)
                         if (debug_opt && !is_hasrun(new_l->cl_option)) {
                             struct tm *ftime;
                             ftime = localtime(&new_l->cl_nextexe);
-                            debug("  from last conf: %s next exec %d/%d/%d"
-                                  " wday:%d %02d:%02d:%02d (system time)",
-                                  new_l->cl_shell,
-                                  (ftime->tm_mon + 1), ftime->tm_mday,
-                                  (ftime->tm_year + 1900), ftime->tm_wday,
-                                  ftime->tm_hour, ftime->tm_min, ftime->tm_sec);
+                            debug
+                                ("  from last conf: '%s' next exec %04d-%02d-%02d"
+                                 " wday:%d %02d:%02d:%02d (system time)",
+                                 new_l->cl_shell, (ftime->tm_year + 1900),
+                                 (ftime->tm_mon + 1), ftime->tm_mday,
+                                 ftime->tm_wday, ftime->tm_hour, ftime->tm_min,
+                                 ftime->tm_sec);
                         }
 
                         break;
@@ -596,6 +597,9 @@ read_file(const char *file_name, cf_t * cf, int is_system_startup)
         error("could not get time and date of saving");
         goto err;
     }
+    else {
+        debug("file saved at %lu.", t_save);
+    }
 
     if (cf->cf_env_list == NULL)
         cf->cf_env_list = env_list_init();
@@ -853,7 +857,7 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
         else {
             /* job has been stopped during execution :
              * launch it again */
-            warn("job %s did not finish : running it again.", cl->cl_shell);
+            warn("job '%s' did not finish : running it again.", cl->cl_shell);
             set_serial_once(cl->cl_option);
             add_serial_job(cl, -1);
         }
@@ -910,7 +914,7 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
                 else {
                     /* run bootrun jobs */
                     cl->cl_remain = cl->cl_runfreq;
-                    debug("   boot-run %s", cl->cl_shell);
+                    debug("   boot-run '%s'", cl->cl_shell);
                     if (!is_lavg(cl->cl_option)) {
                         set_serial_once(cl->cl_option);
                         add_serial_job(cl, -1);
@@ -939,6 +943,12 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
         }
     }
     else {                      /* is_td(cl->cl_option) */
+        if (cl->cl_timefreq < 10) {
+            error("Invalid timefreq %ld for job '%s': setting to 1 day",
+                  cl->cl_timefreq, cl->cl_shell);
+            cl->cl_timefreq = 3600 * 24;
+        }
+
         /* standard @-lines */
         if (is_system_startup && is_runatreboot(cl->cl_option)) {
             cl->cl_nextexe = now;
@@ -956,7 +966,7 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
                 if (cl->cl_nextexe < now || cl->cl_nextexe > TIME_T_MAX) {
                     /* there was an integer overflow! */
                     error
-                        ("Error while setting next exe time for job %s: cl_nextexe"
+                        ("Error while setting next exe time for job '%s': cl_nextexe"
                          " overflowed (case1). now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
                          cl->cl_shell, now, cl->cl_timefreq, cl->cl_nextexe);
                     error
@@ -969,35 +979,32 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
             if (cl->cl_nextexe != LONG_MAX) {
                 cl->cl_nextexe += slept;
                 if (cl->cl_nextexe < now || cl->cl_nextexe > TIME_T_MAX) {
-                    /* there was an integer overflow! */
+                    /* either there was an integer overflow, or the slept time is incorrect
+                     * (e.g. fcron didn't shut down cleanly and the fcrontab wasn't saved correctly) */
                     error
-                        ("Error while setting next exe time for job %s: cl_nextexe"
-                         " overflowed (case2). now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
+                        ("Error while setting next exe time for job '%s': cl_nextexe"
+                         " overflowed (case2). now=%lu, cl_timefreq=%lu, cl_nextexe=%lu. "
+                         "Did fcron shut down cleanly?",
                          cl->cl_shell, now, cl->cl_timefreq, cl->cl_nextexe);
                     error
-                        ("Setting cl_nextexe to TIME_T_MAX=%ld to prevent an infinite loop.",
-                         TIME_T_MAX);
-                    cl->cl_nextexe = TIME_T_MAX;
+                        ("Setting cl_nextexe to now+cl_timefreq to prevent an infinite loop.");
+                    cl->cl_nextexe = now + cl->cl_timefreq;
+                    error("next execution will now be at %ld.", cl->cl_nextexe);
                 }
             }
         }
 
-        if (cl->cl_timefreq < 10) {
-            error("Invalid timefreq for %s: set to 1 day", cl->cl_shell);
-            cl->cl_timefreq = 3600 * 24;
-        }
-
         insert_nextexe(cl);
     }
 
     if (debug_opt && !(is_runonce(cl->cl_option) && is_hasrun(cl->cl_option))) {
         struct tm *ftime;
         ftime = localtime(&(cl->cl_nextexe));
-        debug("  cmd %s next exec %d/%d/%d wday:%d %02d:%02d:%02d"
+        debug("  cmd '%s' next exec %04d-%02d-%02d wday:%d %02d:%02d:%02d"
               " (system time)",
-              cl->cl_shell, (ftime->tm_mon + 1), ftime->tm_mday,
-              (ftime->tm_year + 1900), ftime->tm_wday,
-              ftime->tm_hour, ftime->tm_min, ftime->tm_sec);
+              cl->cl_shell, (ftime->tm_year + 1900), (ftime->tm_mon + 1),
+              ftime->tm_mday, ftime->tm_wday, ftime->tm_hour, ftime->tm_min,
+              ftime->tm_sec);
     }
 
     /* add the current line to the list, and allocate a new line */
@@ -1055,7 +1062,7 @@ delete_file(const char *user_name)
         for (l = lavg_list_first(lavg_list); l != NULL;
              l = lavg_list_next(lavg_list))
             if (l->l_line->cl_file == file) {
-                debug("removing %s from lavg queue", l->l_line->cl_shell);
+                debug("removing '%s' from lavg queue", l->l_line->cl_shell);
                 lavg_list_remove_cur(lavg_list);
             }
 
@@ -1067,7 +1074,7 @@ delete_file(const char *user_name)
                         alloc_safe(serial_array_size * sizeof(cl_t *),
                                    "serial queue");
                 }
-                debug("removing %s from serial queue",
+                debug("removing '%s' from serial queue",
                       serial_array[i]->cl_shell);
                 serial_num--;
                 serial_array[i]->cl_numexe--;
