@@ -173,11 +173,11 @@ print_schedule(void)
         explain(" File %s", cf->cf_user);
         for (cl = cf->cf_line_base; cl; cl = cl->cl_next) {
             ftime = localtime(&(cl->cl_nextexe));
-            explain("  cmd %s next exec %d/%d/%d wday:%d %02d:%02d"
+            explain("  cmd '%s' next exec %04d-%02d-%02d wday:%d %02d:%02d"
                     " (system time)",
-                    cl->cl_shell, (ftime->tm_mon + 1), ftime->tm_mday,
-                    (ftime->tm_year + 1900), ftime->tm_wday,
-                    ftime->tm_hour, ftime->tm_min);
+                    cl->cl_shell, (ftime->tm_year + 1900), (ftime->tm_mon + 1),
+                    ftime->tm_mday, ftime->tm_wday, ftime->tm_hour,
+                    ftime->tm_min);
 
         }
     }
@@ -832,6 +832,7 @@ main_loop()
         check_signal();
 
         debug("\n");
+
         test_jobs();
 
         while (serial_num > 0 && serial_running < serial_max_running)
