@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -135,12 +135,15 @@ usage(void)
 {
     fprintf(stderr,
             "fcrondyn [-i]\n"
-            "fcrondyn -x 'command'\n"
+            "fcrondyn -x {command}\n"
             "fcrondyn -h\n"
+            "  -i         run fcrontab in interactive mode.\n"
+            "  -x         execute one command (in batch mode)\n"
             "  -c f       make fcrontab use config file f.\n"
             "  -d         set up debug mode.\n"
             "  -h         display this help message.\n"
-            "  -V         display version & infos about fcrondyn.\n" "\n");
+            "  -V         display version & infos about fcrondyn.\n" "\n"
+            "To list the available commands, run:\n" "  fcrondyn -x help\n");
 
     exit(EXIT_ERR);
 }
@@ -458,14 +461,14 @@ connect_fcron(void)
         die_e("Cannot connect() to fcron (check if fcron is running)");
 
 /* Nothing to do on the client side if we use SO_PASSCRED */
-#ifndef SO_PASSCRED
+#if !defined(SO_PASSCRED) && !defined(HAVE_GETPEERUCRED) && !defined(HAVE_GETPEEREID)
     if (authenticate_user_password(fd) == ERR) {
         fprintf(stderr, "Invalid password or too many authentication failures"
                 " (try to connect later).\n(In the later case, fcron rejects all"
                 " new authentication during %d secs)\n", AUTH_WAIT);
         die("Unable to authenticate user");
     }
-#endif                          /* SO_PASSCRED */
+#endif                          /* SO_PASSCRED HAVE_GETPEERUCRED HAVE_GETPEEREID */
 
     return fd;
 
@@ -574,8 +577,10 @@ talk_fcron(char *cmd_str, int fd)
         return ERR;
     }
 
-    while ((read_len = (size_t) recv(fd, buf, sizeof(buf), 0)) >= 0
+
+    while ((read_len = (size_t) recv(fd, buf, sizeof(buf) - 1, 0)) >= 0
            || errno == EINTR) {
+
         if (errno == EINTR && debug_opt)
             fprintf(stderr, "got EINTR ...\n");
         else if (read_len > sizeof(buf)) {
@@ -591,16 +596,20 @@ talk_fcron(char *cmd_str, int fd)
             return ERR;
         }
         else {
-            if (write(STDOUT_FILENO, buf, read_len) < 0)
-                error_e("unable to write() to STDOUT_FILENO");
+            /* ensure the string is terminated by a '\0' for when we'll printf() it */
+            buf[read_len] = '\0';
+            printf("%s", buf);
+
+            /* check for the end of command output marker */
             if (read_len >= sizeof(END_STR) &&
                 strncmp(&buf[read_len - sizeof(END_STR)], END_STR,
                         sizeof(END_STR)) == 0)
                 break;
         }
     }
-    if (read_len < 0)
+    if (read_len < 0) {
         error_e("error in recv()");
+    }
 
     if (!existing_connection)
         xclose_check(&fd, "unix socket");
@@ -686,6 +695,13 @@ interactive_mode(int fd)
 
     while (1) {
         line_read = readline("fcrondyn> ");
+
+        if (line_read == NULL) {
+            /* Handle EOF gracefully and move past the prompt line */
+            printf("\n");
+            break;
+        }
+
         return_code = talk_fcron(line_read, fd);
 
 #ifdef HAVE_READLINE_HISTORY
