@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,28 @@
 #include "global.h"
 #include "mem.h"
 
+#if defined(__sun)
+/* Solaris 10 has no strndup() */
+char *
+strndup(const char *s, size_t n)
+    /* Written by Kaveh R. Ghazi <ghazi@caip.rutgers.edu> */
+{
+    char *result;
+    size_t len = strlen(s);
+
+    if (n < len)
+        len = n;
+
+    result = (char *)malloc(len + 1);
+    if (!result)
+        return 0;
+
+    memcpy(result, s, len);
+    result[len] = '\0';
+    return (result);
+}
+#endif
+
 char *
 strdup2(const char *str)
 {
@@ -48,6 +70,7 @@ strndup2(const char *str, size_t n)
     if (str == NULL)
         return NULL;
 
+    /* note: if n==0 then ptr will be an empty string (non-NULL) */
     ptr = strndup(str, n);
 
     if (!ptr)
