@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,6 +53,9 @@
 
 
 /* functions prototypes */
+#if defined(__sun)
+extern char *strndup(const char *s, size_t n);  /* Solaris 10 has no strndup() */
+#endif
 extern char *strdup2(const char *);
 extern char *strndup2(const char *, size_t n);
 extern void *alloc_safe(size_t len, const char *desc);
