@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ int
 save_str(int fd, short int type, char *str, char *write_buf, int *buf_used)
 /* save a string of type "type" in a binary fcrontab file */
 {
-    short int size = strlen(str);
+    short int size = (str != NULL) ? strlen(str) : 0;
     int write_len = sizeof(type) + sizeof(size) + size;
 
     if (write_len > WRITE_BUF_LEN - *buf_used)
@@ -306,6 +306,16 @@ write_file_to_disk(int fd, struct cf_t *file, time_t time_date)
         return ERR;
     }
 
+    /* Make sure the data is fully synchronize to disk before files are renamed 
+     * to their final destination.
+     * This is to avoid cases where the file name (meta-data) would be updated,
+     * and there is a crash before the data is fully written: not sure if that
+     * is possible, but better safe than sorry! */
+    if (fdatasync(fd) < 0) {
+        error_e("could not fdatasync() %s's fcrontab", file->cf_user);
+        return ERR;
+    }
+
     return OK;
 }
 
